@@ -9,7 +9,10 @@ def hyphenate(text, margin=1):
 	For example, it'd be a bit silly to break a word like 'erikoinen' at 'e-rikoinen'.
 	With default margin of 1, it breaks like 'eri-koinen'.
 	"""
-	kerake = "bcdfghjklmnpqrstvwxz"			# eli konsonantit.
+	
+	# Uh, sorry, my comments are in Finnish. Well, I can hardly think anybody else than Finnish people reading this...
+	
+	kerake = "bcdfghjklmnpqrstvwxz"		# eli konsonantit.
 	kerake = list( kerake + kerake.upper() )
 	vokaali = "aeiouyäöå"
 	vokaali = list( vokaali + vokaali.upper() )
@@ -21,16 +24,16 @@ def hyphenate(text, margin=1):
 	
 	# looppi, jossa siis sanaa edetään kirjain kerrallaan, ja sen mukaan, mitä vastaan tulee, yritetään päätellä tavurakenne
 	
-	for sana in text.split(' '):			# homma toimii niin, että varmistuneita tavuja tungetaan
-		tavutettu = ''						# tavutettu-muuttujaan
-		buff = ''					# parhaillaan tavu jota kursitaan kasaan, on buffissa.
-		rajatapaus = ''		# rajatapaus tarkoittaa kirjainta, josta ei etukäteen tiedä,
-											# miten tavuraja menee. esim: ka-Na, kaN-nu
-		raja = ''			# muuttuja raja sisältää tavuviivamerkin, joka tungetaan aina buffin alkuun, siis tavujen väliin.
-		for i, c in enumerate(sana):				# Tarkoitan btw. alla kommenteissa isolla kirjaimella kulloistakin 
-													# c:tä eli käsittelyssä olevaa merkkiä.
-			if c in vokaali:								# ja suluissa olevalla rajatapausta, joka jäi edelliseltä 
-															# kierrokselta päättämättä kummalle puolelle tavuviivaa kuuluu.
+	for sana in text.split(' '):		# Homma toimii niin, että varmistuneita tavuja tungetaan
+		tavutettu = ''							# tavutettu-muuttujaan
+		buff = ''						# parhaillaan tavu jota kursitaan kasaan, on buffissa.
+		rajatapaus = ''					# rajatapaus tarkoittaa kirjainta, josta ei etukäteen tiedä ...
+												# miten tavuraja menee. esim: ka-Na, kaN-nu
+		raja = ''			# muuttuja raja sisältää tavuviivamerkin, joka tungetaan buffin alkuun, eli tavujen väliin.
+		for i, c in enumerate(sana):				# Alla esimerkkikommenteissa iso kirjain senhetkistä 
+															# c-muuttujaa eli käsittelyssä olevaa merkkiä.
+			if c in vokaali:						# Suluissa oleva taas on rajatapaus, joka jäi edelliseltä 
+															# ...kierrokselta epäselväksi kummalle puolelle tavuviivaa kuuluu.
 				if rajatapaus != '':				# ha(l)Oo, a(k)U. jooh, ei pitkää konsonanttia. -> tavuraja
 					buff = raja + rajatapaus+c
 					rajatapaus = ''
@@ -49,12 +52,12 @@ def hyphenate(text, margin=1):
 					buff += c
 			elif c in kerake:
 				if rajatapaus != '':
-					if c == rajatapaus and i < len(sana)-1:	# ka(n)Nu, huu(s)Si. kaksi peräkkäistä samaa konsonanttia -> tavuraja
-						tavutettu += rajatapaus					# Jännä tietysti et aivan sanan vikalle kirjaimelle tää ei päde.
+					if c == rajatapaus and i < len(sana)-1:	# ka(n)Nu, huu(s)Si. kaksi samaa konsonanttia -> tavuraja
+						tavutettu += rajatapaus				# Jännä tietysti et aivan sanan vikalle kirjaimelle tää ei päde.
 						rajatapaus = ''
 						buff = raja + c
-					else:							# ka(r)Kki, ku(l)Ttuuri, sa(r)Ka tavuydin on jo ohi, ja tavu on heitetty jo
-													# tavutettujen pinoon, mutta lopussa onkin yllättävän paljon kamaa! 
+					else:							# ka(r)Kki, ku(l)Ttuuri, sa(r)Ka tavuydin on jo ohi, 
+														# mutta lopussa onkin yllättävän paljon kamaa! 
 						if tavutettu[-1:] in vokaali:	# esim. särk-kä vai sar-ka? ei tiedetä -> rajatapaus.
 							tavutettu += rajatapaus
 							rajatapaus = c
@@ -63,7 +66,7 @@ def hyphenate(text, margin=1):
 							raja = tavuviiva
 							rajatapaus = ''
 							buff = raja+ c
-				elif buff == tavuviiva or buff =='':	# Riku, Kronikka. Aloitetaan puhtaalta pöydältä.
+				elif buff == tavuviiva or buff =='':	# Riku, Kronikka. Puhtaalta pöydältä.
 					buff = raja+ c
 				elif buff[-2:] in pitkat:		# ääLiö vai pääLlikkö? -> rajatapaus.
 					tavutettu += buff
@@ -107,9 +110,18 @@ if __name__ == "__main__":
 	import sys
 	try:
 		margin=int(sys.argv[1])
-		text=' '.join(sys.argv[2:])
+		try:
+			text=' '.join(sys.argv[2:])
+		except:
+			print("Usage: hyphenate_finnish.py [margin] text... OR inside Python: from hyphenate_finnish import hyphenate; hyphenate(text, margin) ")
+			sys.exit(2)
 	except:
-		print("Usage: hyphenate_finnish.py [margin] text... OR inside Python: from hyphenate_finnish import hyphenate; hyphenate(text, margin) ")
-		sys.exit(2)
+		margin = 1
+		try:
+			text=' '.join(sys.argv[1:])
+		except:
+			print("Usage: hyphenate_finnish.py [margin] text... OR inside Python: from hyphenate_finnish import hyphenate; hyphenate(text, margin) ")
+			sys.exit(2)
+
 	hyp = hyphenate(text, margin=margin)
 	print(hyp)
\ No newline at end of file
